import { HeadersOption } from '@managed-api/commons-core';
import { Repositories, Repository } from '../definitions/Repository';
import { CommonError, ErrorStrategyOption, Message } from '../errorStrategy';
export interface CreateRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    body: {
        name: string;
        description?: string;
        scmId?: string;
        forkable?: boolean;
        defaultBranch?: string;
    };
}
export interface CreateRepositoryResponseOK extends Repository {
}
export interface CreateRepositoryResponseError extends CommonError {
}
export interface GetRepositoriesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * The limit parameter indicates how many results to return per page.
     */
    limit?: number;
    /**
     * The start parameter indicates which item should be used as the first item in the page of results.
     */
    start?: number;
}
export interface GetRepositoriesResponseOK extends Repositories {
}
export interface GetRepositoriesResponseError extends CommonError {
}
export interface DeleteRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
}
export declare type DeleteRepositoryResponseOK = Message | undefined;
export interface DeleteRepositoryResponseError extends CommonError {
}
export interface GetRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
}
export interface GetRepositoryResponseOK extends Repository {
}
export interface GetRepositoryResponseError extends CommonError {
}
export interface UpdateRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    name?: string;
    description?: string;
    forkable?: boolean;
    project?: {
        key: string;
    };
    public?: boolean;
    defaultBranch?: string;
}
export interface UpdateRepositoryResponseOK extends Repository {
}
export interface UpdateRepositoryResponseError extends CommonError {
}
//# sourceMappingURL=repository.d.ts.map