import { HeadersOption } from '@managed-api/commons-core';
import { Commits, Commit } from '../../definitions/Commit';
import { CommonError, ErrorStrategyOption } from '../../errorStrategy';
export interface GetRepositoryCommitsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * if true, the commit history of the specified file will be followed past renames. Only valid for a path to a single file.
     */
    followRenames?: boolean;
    /**
     * true to ignore missing commits, false otherwise
     */
    ignoreMissing?: boolean;
    /**
     * if present, controls how merge commits should be filtered. Can be either exclude, to exclude merge commits, include, to include both merge commits and non-merge commits or only, to only return merge commits.
     */
    merges?: string;
    /**
     * an optional path to filter commits by
     */
    path?: string;
    /**
     * the commit ID or ref (exclusively) to retrieve commits after
     */
    since?: string;
    /**
     * the commit ID (SHA1) or ref (inclusively) to retrieve commits before
     */
    until?: string;
    /**
     * optionally include the total number of commits and total number of unique authors
     */
    withCounts?: boolean;
    /**
     * if present the service adds avatar URLs for commit authors. Should be an integer specifying the desired size in pixels. If the parameter is not present, avatar URLs will not be set
     */
    avatarSize?: string;
    /**
     * the desired scheme for the avatar URL. If the parameter is not present URLs will use the same scheme as this request
     */
    avatarScheme?: string;
    /**
     * The limit parameter indicates how many results to return per page.
     */
    limit?: number;
    /**
     * The start parameter indicates which item should be used as the first item in the page of results.
     */
    start?: number;
}
export interface GetRepositoryCommitsResponseOK extends Commits {
}
export interface GetRepositoryCommitsResponseError extends CommonError {
}
export interface GetRepositoryCommitRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the commit ID to retrieve
     */
    commitId: string;
    /**
     * an optional path to filter the commit by. If supplied the details returned may not be for the specified commit. Instead, starting from the specified commit, they will be the details for the first commit affecting the specified path.
     */
    path?: string;
}
export interface GetRepositoryCommitResponseOK extends Commit {
}
export interface GetRepositoryCommitResponseError extends CommonError {
}
//# sourceMappingURL=commit.d.ts.map