import { HeadersOption } from '@managed-api/commons-core';
import { Activities } from '../../definitions/Activity';
import { Participant } from '../../definitions/Participant';
import { PullRequest, PullRequests } from '../../definitions/PullRequest';
import { CommonError, ErrorStrategyOption } from '../../errorStrategy';
export interface GetRepositoryPullRequestsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * (optional, defaults to INCOMING) the direction relative to the specified repository. Either INCOMING or OUTGOING.
     */
    direction?: 'INCOMING' | 'OUTGOING';
    /**
     * (optional) a fully-qualified branch ID to find pull requests to or from, such as refs/heads/master
     */
    at?: string;
    /**
     * (optional, defaults to OPEN). Supply ALL to return pull request in any state. If a state is supplied only pull requests in the specified state will be returned. Either OPEN, DECLINED or MERGED.
     */
    state?: 'OPEN' | 'DECLINED' | 'MERGED';
    /**
     * (optional, defaults to NEWEST) the order to return pull requests in, either OLDEST (as in: "oldest first") or NEWEST.
     */
    order?: 'NEWEST' | 'OLDEST';
    /**
     * (optional) defaults to true, whether to return additional pull request attributes
     */
    withAttributes?: boolean;
    /**
     * (optional) defaults to true, whether to return additional pull request properties
     */
    withProperties?: boolean;
    /**
     * (optional) If specified, only pull requests where the title or description contains the supplied string will be returned.
     */
    filterText?: string;
    /**
     * The limit parameter indicates how many results to return per page.
     */
    limit?: number;
    /**
     * The start parameter indicates which item should be used as the first item in the page of results.
     */
    start?: number;
}
export interface GetRepositoryPullRequestsResponseOK extends PullRequests {
}
export interface GetRepositoryPullRequestsResponseError extends CommonError {
}
export interface CreateRepositoryPullRequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    body: {
        title: string;
        description?: string;
        fromRef: {
            id: string;
        };
        toRef: {
            id: string;
        };
        reviewers?: {
            user: {
                name: string;
            };
        }[];
    };
}
export interface CreateRepositoryPullRequestResponseOK extends PullRequest {
}
export interface CreateRepositoryPullRequestResponseError extends CommonError {
}
export interface GetRepositoryPullRequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
}
export interface GetRepositoryPullRequestResponseOK extends PullRequest {
}
export interface GetRepositoryPullRequestResponseError extends CommonError {
}
export interface UpdateRepositoryPullRequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    body: {
        version: number;
        title?: string;
        description?: string;
        reviewers?: {
            user: {
                name: string;
            };
        }[];
        toRef?: {
            id: string;
        };
    };
}
export interface UpdateRepositoryPullRequestResponseOK extends PullRequest {
}
export interface UpdateRepositoryPullRequestResponseError extends CommonError {
}
export interface DeleteRepositoryPullRequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    body: {
        version: number;
    };
}
export declare type DeleteRepositoryPullRequestResponseOK = undefined;
export interface DeleteRepositoryPullRequestResponseError extends CommonError {
}
export interface GetRepositoryPullRequestActivitiesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    /**
     * (optional) the ID of the activity item to use as the first item in the returned page
     */
    fromId?: number;
    /**
     * (required if fromId is present) the type of the activity item specified by fromId (either COMMENT or ACTIVITY)
     */
    fromType?: 'COMMENT' | 'ACTIVITY';
    /**
     * The limit parameter indicates how many results to return per page.
     */
    limit?: number;
    /**
     * The start parameter indicates which item should be used as the first item in the page of results.
     */
    start?: number;
}
export interface GetRepositoryPullRequestActivitiesResponseOK extends Activities {
}
export interface GetRepositoryPullRequestActivitiesResponseError extends CommonError {
}
export interface DeclineRepositoryPullRequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    /**
     * the current version of the pull request. If the server's version isn't the same as the specified version the operation will fail. To determine the current version of the pull request it should be fetched from the server prior to this operation. Look for the 'version' attribute in the returned JSON structure.
     */
    version: number;
}
export interface DeclineRepositoryPullRequestResponseOK extends PullRequest {
}
export interface DeclineRepositoryPullRequestResponseError extends CommonError {
}
export interface MergeRepositoryPullRequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    /**
     * the current version of the pull request. If the server's version isn't the same as the specified version the operation will fail. To determine the current version of the pull request it should be fetched from the server prior to this operation. Look for the 'version' attribute in the returned JSON structure.
     */
    version: number;
}
export interface MergeRepositoryPullRequestResponseOK extends PullRequest {
}
export interface MergeRepositoryPullRequestResponseError extends CommonError {
}
export interface ReopenRepositoryPullRequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    /**
     * the current version of the pull request. If the server's version isn't the same as the specified version the operation will fail. To determine the current version of the pull request it should be fetched from the server prior to this operation. Look for the 'version' attribute in the returned JSON structure.
     */
    version: number;
}
export interface ReopenRepositoryPullRequestResponseOK extends PullRequest {
}
export interface ReopenRepositoryPullRequestResponseError extends CommonError {
}
export interface ChangeRepositoryPullRequestStatusRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    /**
     * the slug for the user changing their status
     */
    userSlug: string;
    body: {
        status: 'APPROVED' | 'UNAPPROVED' | 'NEEDS_WORK';
    };
}
export interface ChangeRepositoryPullRequestStatusResponseOK extends Participant {
}
export interface ChangeRepositoryPullRequestStatusResponseError extends CommonError {
}
//# sourceMappingURL=pullRequest.d.ts.map