import { HeadersOption } from '@managed-api/commons-core';
import { Comment, Comments } from '../../../definitions/Comment';
import { CommonError, ErrorStrategyOption } from '../../../errorStrategy';
export interface GetRepositoryPullRequestCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    /**
     * ACTIVE to stream the active comments; ORPHANED to stream the orphaned comments; ALL to stream both the active and the orphaned comments;
     */
    anchorState?: 'ACTIVE' | 'ORPHANED' | 'ALL';
    /**
     * EFFECTIVE to stream the comments related to the effective diff of the pull request; RANGE to stream comments related to a commit range between two arbitrary commits (requires fromHash and toHash); COMMIT to stream comments related to a commit between two arbitrary commits (requires fromHash and toHash)
     */
    diffType?: 'EFFECTIVE' | 'RANGE' | 'COMMIT';
    /**
     * the from commit hash to stream comments for a RANGE or COMMIT arbitrary change scope
     */
    fromHash?: string;
    /**
     * the path to stream comments for a given path
     */
    path: string;
    state?: string;
    /**
     * the to commit hash to stream comments for a RANGE or COMMIT arbitrary change scope
     */
    toHash?: string;
    /**
     * The limit parameter indicates how many results to return per page.
     */
    limit?: number;
    /**
     * The start parameter indicates which item should be used as the first item in the page of results.
     */
    start?: number;
}
export interface GetRepositoryPullRequestCommentsResponseOK extends Comments {
}
export interface GetRepositoryPullRequestCommentsResponseError extends CommonError {
}
export interface CreateRepositoryPullRequestCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    body: {
        text: string;
        parent?: {
            id: number;
        };
        anchor?: {
            /**
             * diffType refers to the type of diff the comment was added on. For backwards compatibility purposes if no diffType is provided and no fromHash/toHash pair is provided the diffType will be resolved to 'EFFECTIVE'. In any other cases the diffType is REQUIRED.
             */
            diffType?: string;
            /**
             * For line comments, 'line' refers to the line in the diff that the comment should apply to.
             */
            line?: number;
            /**
             * 'lineType' refers to the type of diff hunk, which can be:
             ** 'ADDED' - for an added line;
             ** 'REMOVED' - for a removed line; or
             ** 'CONTEXT' - for a line that was unmodified but is in the vicinity of the diff.
             */
            lineType?: 'ADDED' | 'REMOVED' | 'CONTEXT';
            /**
             * 'fileType' refers to the file of the diff to which the anchor should be attached - which is of relevance when displaying the diff in a side-by-side way. Currently the supported values are:
             ** 'FROM' - the source file of the diff
             ** 'TO' - the destination file of the diff
             */
            fileType?: 'FROM' | 'TO';
            /**
             * Also, fromHash and toHash refer to the sinceId / untilId (respectively) used to produce the diff on which the comment was added.
             */
            fromHash?: string;
            /**
             * For file and line comments, 'path' refers to the path of the file to which the comment should be applied
             */
            path?: string;
            /**
             * For file and line comments, 'srcPath' refers to the path the that file used to have (only required for copies and moves)
             */
            srcPath?: string;
            /**
             * Also, fromHash and toHash refer to the sinceId / untilId (respectively) used to produce the diff on which the comment was added.
             */
            toHash?: string;
        };
        severity?: string;
        state?: string;
    };
}
export interface CreateRepositoryPullRequestCommentResponseOK extends Comment {
}
export interface CreateRepositoryPullRequestCommentResponseError extends CommonError {
}
export interface DeleteRepositoryPullRequestCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    /**
     * the ID of the comment to retrieve
     */
    commentId: number;
    /**
     * The expected version of the comment. This must match the server's version of the comment or the delete will fail. To determine the current version of the comment, the comment should be fetched from the server prior to the delete. Look for the 'version' attribute in the returned JSON structure.
     */
    version: number;
}
export declare type DeleteRepositoryPullRequestCommentResponseOK = undefined;
export interface DeleteRepositoryPullRequestCommentResponseError extends CommonError {
}
export interface UpdateRepositoryPullRequestCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    /**
     * the ID of the comment to retrieve
     */
    commentId: number;
    body: {
        version: number;
        text?: string;
        severity?: string;
        state?: string;
    };
}
export interface UpdateRepositoryPullRequestCommentResponseOK extends Comment {
}
export interface UpdateRepositoryPullRequestCommentResponseError extends CommonError {
}
export interface GetRepositoryPullRequestCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the parent project key
     */
    projectKey: string;
    /**
     * the repository slug
     */
    repositorySlug: string;
    /**
     * the ID of the pull request within the repository
     */
    pullRequestId: number;
    /**
     * the ID of the comment to retrieve
     */
    commentId: number;
}
export interface GetRepositoryPullRequestCommentResponseOK extends Comment {
}
export interface GetRepositoryPullRequestCommentResponseError extends CommonError {
}
//# sourceMappingURL=comment.d.ts.map