import { HeadersOption } from '@managed-api/commons-core';
import { DetailedUser, DetailedUsers } from '../definitions/User';
import { CommonError, ErrorStrategyOption } from '../errorStrategy';
export interface GetUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * if specified only users with usernames, display name or email addresses containing the supplied string will be returned
     */
    filter?: string;
}
export interface GetUsersResponseOK extends DetailedUsers {
}
export interface GetUsersResponseError extends CommonError {
}
export interface DeleteUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the username identifying the user to delete
     */
    name: string;
}
export interface DeleteUserResponseOK extends DetailedUser {
}
export interface DeleteUserResponseError extends CommonError {
}
export interface CreateUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the username for the new user
     */
    name: string;
    /**
     * the password for the new user
     */
    password: string;
    /**
     * the display name for the new user
     */
    displayName: string;
    /**
     * the e-mail address for the new user
     */
    emailAddress: string;
    /**
     * true to add the user to the default group, which can be used to grant them a set of initial permissions; otherwise, false to not add them to a group
     */
    addToDefaultGroup?: boolean;
    /**
     * if present and not false instead of requiring a password, the create user will be notified via email their account has been created and requires a password to be reset. This option can only be used if a mail server has been configured
     */
    notify?: string;
}
export declare type CreateUserResponseOK = undefined;
export interface CreateUserResponseError extends CommonError {
}
export interface UpdateCurrentUserRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        name: string;
        displayName: string;
        email: string;
    };
}
export interface UpdateCurrentUserResponseOK extends DetailedUser {
}
export interface UpdateCurrentUserResponseError extends CommonError {
}
//# sourceMappingURL=user.d.ts.map